.. _abrechnung-dev-contributing:

******************
Contributing
******************

As Users
--------

In case you encounter bugs or have ideas for new and useful features don't hesitate to open an
`issue <https://github.com/SFTtech/abrechnung/issues>`_ and start a discussion.

As Developers
-------------

Get started by setting up a local :ref:`development environment <abrechnung-dev-setup>` and reading through the
:ref:`abrechnung-dev-architecture` overview and then start hacking.
`Pull requests <https://github.com/SFTtech/abrechnung/pulls>`_ are always welcome!